﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace Example
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();
		}

		// NOTE: To compile this example you need to add a proper references to the "arial.ttf", "arialbd.ttf" and "timesbi.ttf" set their "Build Action" to "Embedded Resource".

		// Resources
		private static EmbeddedResource Arial = new EmbeddedResource("Siberix.arial.ttf");
		private static EmbeddedResource ArialBold = new EmbeddedResource("Siberix.arialbd.ttf");
		private static EmbeddedResource TimesNewRomanItalic = new EmbeddedResource("Siberix.timesi.ttf");
		private static EmbeddedResource Font1 = new EmbeddedResource("Siberix.font.ttf");
		private static EmbeddedResource Image1 = new EmbeddedResource("Siberix.image.jpg");

		// Fonts
		private static Siberix.Graphics.Font fnt1 = new Siberix.Graphics.Font(Font1.Stream, 35);
		private static Siberix.Graphics.Font fnt2 = new Siberix.Graphics.Font(Arial.Stream, 12);
		private static Siberix.Graphics.Font fnt3 = new Siberix.Graphics.Font(Arial.Stream, 10);
		private static Siberix.Graphics.Font fnt4 = new Siberix.Graphics.Font(Arial.Stream, 135);
		private static Siberix.Graphics.Font fnt5 = new Siberix.Graphics.Font(ArialBold.Stream, 12);
		private static Siberix.Graphics.Font fnt6 = new Siberix.Graphics.Font(TimesNewRomanItalic.Stream, 12);
		private static Siberix.Graphics.Font fnt7 = new Siberix.Graphics.Font(ArialBold.Stream, 35);
		private static Siberix.Graphics.Font fnt8 = new Siberix.Graphics.Font(Arial.Stream, 16);
		private static Siberix.Graphics.Font fnt9 = new Siberix.Graphics.Font(TimesNewRomanItalic.Stream, 18);
		
		// Images
		private static Siberix.Graphics.Image img1 = new Siberix.Graphics.Image(Image1.Stream);

		// Binding (works with public classes only)
		public class Person
		{
			public string Name { get; set; }
			public DateTime Birthday { get; set; }
			public int Level { get; set; }
			public List<Task> Tasks { get; set; }
		}

		public class Task
		{
			public string Id { get; set; }
			public string Description { get; set; }
		}

		public class ValueFormatter : Siberix.Report.Data.IValueFormatter
		{
			public string Id
			{
				get
				{
					return "vf1";
				}
			}

			public string Format(object value)
			{
				if (value != null)
				{
					DateTime dt = (DateTime)value;

					return "[ " + dt.Year + " / " + dt.ToString("MMM") + " / " + dt.Day + " ]";
				}

				return null;
			}
		}

		// Buttons
		private void btn1_Click(object sender, RoutedEventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();

			sfd.Filter = "PDF Files (.pdf)|*.pdf";
			sfd.FilterIndex = 1;
			sfd.DefaultExt = "*.pdf";

			bool? result = sfd.ShowDialog();

			if ((result != null) && (result == true))
			{
				Stream stream = sfd.OpenFile();

				Siberix.Report.Report report = CreateReport();

				// Publish
				report.Publish(stream, Siberix.Report.FileFormat.PDF);

				stream.Close();
			}
		}

		private void btn2_Click(object sender, RoutedEventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();

			sfd.Filter = "XPS Files (.xps)|*.xps";
			sfd.FilterIndex = 1;
			sfd.DefaultExt = "*.xps";

			bool? result = sfd.ShowDialog();

			if ((result != null) && (result == true))
			{
				Stream stream = sfd.OpenFile();

				Siberix.Report.Report report = CreateReport();

				// Publish
				report.Publish(stream, Siberix.Report.FileFormat.XPS);

				stream.Close();
			}
		}

		private void btn3_Click(object sender, RoutedEventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();

			sfd.Filter = "LEAF Files (.leaf)|*.leaf";
			sfd.FilterIndex = 1;
			sfd.DefaultExt = "*.leaf";

			bool? result = sfd.ShowDialog();

			if ((result != null) && (result == true))
			{
				Stream stream = sfd.OpenFile();

				Siberix.Report.Report report = CreateReport();

				// Publish
				report.Publish(stream, Siberix.Report.FileFormat.LEAF);

				stream.Close();
			}
		}

		private void btn4_Click(object sender, RoutedEventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();

			sfd.Filter = "XML Files (.xml|*.xml";
			sfd.FilterIndex = 1;
			sfd.DefaultExt = "*.xml";

			bool? result = sfd.ShowDialog();

			if ((result != null) && (result == true))
			{
				Stream stream = sfd.OpenFile();

				Siberix.Report.Report report = CreateReport();

				// Save
				report.Save(stream);

				stream.Close();
			}
		}

		private void btn5_Click(object sender, RoutedEventArgs e)
		{
			Siberix.Report.Report report = CreateReport();

			// Print
			report.Print("Document");
		}

		#region CreateReport

		private static Siberix.Report.Report CreateReport()
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2010 Siberix Technologies, Canada";

			// Encryption
			//report.Preferences.PDF.Encryptor.Password.User = "test";
			//report.Preferences.PDF.Encryptor.Password.Owner = "siberix";

			report.Preferences.PDF.Encryptor.Permissions.Add = false;
			report.Preferences.PDF.Encryptor.Permissions.Copy = false;
			report.Preferences.PDF.Encryptor.Permissions.Modify = false;
			report.Preferences.PDF.Encryptor.Permissions.Print = true;

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.Horizontal = 35;
			section.Spacings.Top = 20;
			section.Spacings.Bottom = 5;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt3, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt4, new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(240, 240, 240)));

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(600, 5);
			pn.Style = style1;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			// Watermark
			Siberix.Report.Section.IWatermark watermark = section.AddWatermark();
			watermark.Repeat = true;

			Siberix.Report.Text.IText text = watermark.AddText(0, 0, -45);
			text.Style = style2;
			text.AddContent("Elements");

			// Bookmarks
			report.AddBookmark("Contents", "Contents", false);
			report.AddBookmark("Text", "Text", false);
			report.AddBookmark("Local Font", "Local Font", false);
			report.AddBookmark("Hyperlinks", "Hyperlinks", false);
			report.AddBookmark("Image", "Image", false);
			report.AddBookmark("List", "List", false);
			report.AddBookmark("Tree", "Tree", false);
			report.AddBookmark("Flow", "Flow", false);
			report.AddBookmark("Grid", "Grid", false);
			report.AddBookmark("Site", "Site", false);
			report.AddBookmark("Shapes", "Shapes", false);
			report.AddBookmark("Canvas", "Canvas", false);
			report.AddBookmark("Binding", "Binding", false);

			AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 15, "Contents");
			AddContents(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkRed, 10, "Text");
			AddText(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkSlateGray, 15, "Local Font");
			AddLocalFont(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 15, "Hyperlinks");
			AddHyperlinks(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkOrange, 10, "Image");
			AddImage(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkGreen, 10, "List");
			AddList(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkOliveGreen, 10, "Tree");
			AddTree(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkRed, 10, "Flow");
			AddFlow(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkSlateGray, 10, "Grid");
			AddGrid(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 10, "Site");
			AddSite(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkOrange, 10, "Shapes");
			AddShapes(section);

			AddCaption(section, Siberix.Graphics.Brushes.DarkGreen, 10, "Canvas");
			AddCanvas(section);

			section.AddPageBreak();

			AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 10, "Binding");
			AddBinding(section);

			return report;
		}

		#endregion

		#region AddCaption

		private static void AddCaption(Siberix.Report.Section.ISection section, Siberix.Graphics.Brush bgbrush, float width, string caption)
		{
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.White);

			Siberix.Report.IGroup group = section.AddGroup();
			group.Width = new Siberix.Report.RelativeWidth(width);
			group.Background.Brush = bgbrush;
			group.Borders.Corners.All = new Siberix.Report.Corner(null, 5);
			group.Borders.Corners.TopRight = new Siberix.Report.Corner(null, 10);
			group.Borders.Corners.BottomRight = new Siberix.Report.Corner(null, 10);
			group.Paddings.All = 5;
			group.Spacings.Top = 20;
			group.Spacings.Bottom = 15;
			group.KeepWithNext = true;

			Siberix.Report.Text.IText text = group.AddText();
			text.Style = style1;
			text.Id = caption;
			text.AddContent(caption);
		}

		#endregion

		#region AddContents

		private static void AddContents(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);

			// Contents
			Siberix.Report.Grid.IGrid grid = section.AddGrid();
			grid.Width = new Siberix.Report.RelativeWidth(70);

			Siberix.Report.Grid.IColumn column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(90);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(10);

			// Text
			Siberix.Report.Grid.IRow row = grid.AddRow();
			row.Spacings.Top = 5;

			Siberix.Report.Grid.ICell cell = row.AddCell();

			Siberix.Report.Text.IText text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Text", new Siberix.Report.Text.Hyperlink("Text"));

			cell = row.AddCell();

			Siberix.Report.IPageReference pr = cell.AddPageReference("Text");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Local Font
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Local Font", new Siberix.Report.Text.Hyperlink("Local Font"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Local Font");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Hyperlinks
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Hyperlinks", new Siberix.Report.Text.Hyperlink("Hyperlinks"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Hyperlinks");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Image
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Image", new Siberix.Report.Text.Hyperlink("Image"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Image");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// List
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("List", new Siberix.Report.Text.Hyperlink("List"));

			cell = row.AddCell();

			pr = cell.AddPageReference("List");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Tree
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Tree", new Siberix.Report.Text.Hyperlink("Tree"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Tree");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Flow
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Flow", new Siberix.Report.Text.Hyperlink("Flow"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Flow");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Grid
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Grid", new Siberix.Report.Text.Hyperlink("Grid"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Grid");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Site
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Site", new Siberix.Report.Text.Hyperlink("Site"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Site");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Shapes
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Shapes", new Siberix.Report.Text.Hyperlink("Shapes"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Shapes");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Canvas
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Canvas", new Siberix.Report.Text.Hyperlink("Canvas"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Canvas");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Binding
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Binding", new Siberix.Report.Text.Hyperlink("Binding"));

			cell = row.AddCell();

			pr = cell.AddPageReference("Binding");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;
		}

		#endregion

		#region AddText

		private static void AddText(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt6, Siberix.Graphics.Brushes.Red);

			// Text
			Siberix.Report.Text.IText text = section.AddText();
			text.Style = style1;
			text.Width = new Siberix.Report.DirectWidth(350);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive");
			text.AddContent(" \"raisiny\" ", style2);
			text.AddContent("flavor.");
		}

		#endregion

		#region AddLocalFont

		private static void AddLocalFont(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt1, Siberix.Graphics.Brushes.Black);

			// Content
			Siberix.Report.Text.IText text = section.AddText();
			text.Style = style1;
			text.AddContent("ABC");
		}

		#endregion

		#region AddHyperlinks

		private static void AddHyperlinks(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt3, Siberix.Graphics.Brushes.DarkBlue);
			style1.Underline = Siberix.Graphics.Pens.DarkBlue;

			// Hyperlinks
			Siberix.Report.Text.IText text = section.AddText();
			text.Style = style1;
			text.Spacings.Top = 5;
			text.Id = "Link1";
			text.AddContent("Next link", new Siberix.Report.Text.Hyperlink("Link2"));

			text = section.AddText();
			text.Style = style1;
			text.Spacings.Top = 5;
			text.Id = "Link2";
			text.AddContent("Previous link", new Siberix.Report.Text.Hyperlink("Link1"));

			text = section.AddText();
			text.Style = style1;
			text.Spacings.Top = 5;
			text.AddContent("Link to www.siberix.com", new Siberix.Report.Text.Hyperlink("http://www.siberix.com"));
		}

		#endregion

		#region AddImage

		private static void AddImage(Siberix.Report.Section.ISection section)
		{
			Siberix.Report.IImage image = section.AddImage(img1);
			image.Width = new Siberix.Report.DirectWidth(200);
		}

		#endregion

		#region AddList

		private static void AddList(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Red);

			// List
			Siberix.Report.List.IList list = section.AddList();
			list.Indent = 20;
			list.Interval = 5;
			list.Bullets.Type = Siberix.Report.BulletType.Decimal;
			list.Bullets.Template = "{0}.";
			list.Bullets.Style = style1;

			Siberix.Report.List.IItem item = list.AddItem();

			Siberix.Report.Text.IText text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");

			item = list.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");

			Siberix.Report.List.IList sublist = item.AddList();
			sublist.Spacings.Vertical = 5;
			sublist.Indent = 20;
			sublist.Interval = 5;
			sublist.Bullets.Type = Siberix.Report.BulletType.SmallLetters;
			sublist.Bullets.Template = "{0})";
			sublist.Bullets.Style = style2;

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = list.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");
		}

		#endregion

		#region AddTree

		private static void AddTree(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Red);

			// Tree
			Siberix.Report.Tree.ITree tree = section.AddTree();
			tree.Indent = 20;
			tree.Interval = 10;
			tree.Lines.Pen = Siberix.Graphics.Pens.DarkBlue;

			Siberix.Report.Text.IText text = tree.AddText();
			text.Style = style1;
			text.AddContent("Root", style2);

			Siberix.Report.Tree.INode node = tree.AddNode();

			text = node.AddText();
			text.Style = style1;
			text.AddContent("Node ");
			text.AddContent("1", style2);

			node = tree.AddNode();

			text = node.AddText();
			text.Style = style1;
			text.AddContent("Node ");
			text.AddContent("2", style2);

			node = node.AddNode();

			text = node.AddText();
			text.Style = style1;
			text.AddContent("Node ");
			text.AddContent("2.1", style2);

			node = tree.AddNode();

			text = node.AddText();
			text.Style = style1;
			text.AddContent("Node ");
			text.AddContent("3", style2);
		}

		#endregion

		#region AddFlow

		private static void AddFlow(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt3, Siberix.Graphics.Brushes.DarkGreen);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(fnt5, Siberix.Graphics.Brushes.DarkBlue);
			Siberix.Report.Text.Style style4 = new Siberix.Report.Text.Style(fnt7, Siberix.Graphics.Brushes.Red);

			// Flow
			Siberix.Report.Flow.IFlow flow = section.AddFlow();

			Siberix.Report.Flow.IColumn column = flow.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(50);
			column.Borders.Right = new Siberix.Report.Border(Siberix.Graphics.Pens.DarkBlue);
			column.Paddings.Right = 10;

			column = flow.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(50);
			column.Paddings.Left = 10;

			// Left-aligned paragraph
			Siberix.Report.Text.IText text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Left-aligned paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Left;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Right-aligned paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Right-aligned paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Right;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Centered paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Centered paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Center;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Justified paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Justified paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Multiple styles
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Multiple styles");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 30;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. ");
			text.AddContent("Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.", style2);

			// Text with a leader
			text = flow.AddText();
			text.Style = style3;
			text.AddContent("Text with a leader");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Text with a drop-cap
			text = flow.AddText();
			text.Style = style3;
			text.AddContent("Text with a drop-cap");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.DropCap = new Siberix.Report.Text.DropCap('A', style4);
			text.DropCap.Spacings.Right = 7;

			text.AddContent("marone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");
		}

		#endregion

		#region AddGrid

		private static void AddGrid(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);

			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Red);
			style2.FontVariant = Siberix.Report.FontVariant.Subscript;

			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(fnt8, Siberix.Graphics.Brushes.White);

			// Grid
			Siberix.Report.Grid.IGrid grid = section.AddGrid();
			grid.Height = new Siberix.Report.RelativeHeight(100);
			grid.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			grid.Borders.Corners.TopLeft.Pen = Siberix.Graphics.Pens.Black;
			grid.Borders.Corners.TopLeft.Radius = 10;
			grid.Borders.Corners.BottomLeft.Pen = Siberix.Graphics.Pens.Black;
			grid.Borders.Corners.BottomLeft.Radius = 10;

			Siberix.Report.Grid.IColumn column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(20);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.DirectWidth(100);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(20);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(30);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(30);

			// Header
			Siberix.Report.Grid.IHeader header = grid.AddHeader();
			header.Repeat = true;

			Siberix.Report.Grid.IRow row = header.AddRow();
			row.Height = new Siberix.Report.DirectHeight(35);

			Siberix.Report.Grid.ICell cell = row.AddCell();
			cell.ColSpan = 5;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Borders.Corners.TopLeft.Pen = Siberix.Graphics.Pens.Black;
			cell.Borders.Corners.TopLeft.Radius = 10;
			cell.Background = new Siberix.Report.Background(new Siberix.Graphics.Color(235, 50, 50));

			Siberix.Report.Text.IText text = cell.AddText();
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.Style = style3;
			text.Alignment = Siberix.Report.TextAlignment.Center;
			text.AddContent("Header");

			// Footer
			Siberix.Report.Grid.IFooter footer = grid.AddFooter();
			footer.Repeat = true;

			row = footer.AddRow();
			row.Height = new Siberix.Report.DirectHeight(35);

			cell = row.AddCell();
			cell.ColSpan = 5;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Borders.Corners.BottomLeft.Pen = Siberix.Graphics.Pens.Black;
			cell.Borders.Corners.BottomLeft.Radius = 10;
			cell.Background = new Siberix.Report.Background(new Siberix.Graphics.Color(50, 200, 200));

			text = cell.AddText();
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.Style = style3;
			text.Alignment = Siberix.Report.TextAlignment.Center;
			text.AddContent("Footer");

			row = grid.AddRow();

			cell = row.AddCell();
			cell.RowSpan = 2;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("1", style2);
			text.AddContent(" cell");
			text.AddContent("1", style2);
			text.AddContent(" content...");

			cell = row.AddCell();
			cell.RowSpan = 4;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("1", style2);
			text.AddContent(" cell");
			text.AddContent("2", style2);
			text.AddContent(" content... Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			cell = row.AddCell();
			cell.RowSpan = 2;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("1", style2);
			text.AddContent(" cell");
			text.AddContent("3", style2);
			text.AddContent(" content...");

			cell = row.AddCell();
			cell.ColSpan = 2;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("1", style2);
			text.AddContent(" cell");
			text.AddContent("4", style2);
			text.AddContent(" content...");

			row = grid.AddRow();

			cell = row.AddCell();
			cell.ColSpan = 2;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("2", style2);
			text.AddContent(" cell");
			text.AddContent("1", style2);
			text.AddContent(" content... Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique.");

			row = grid.AddRow();

			cell = row.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("3", style2);
			text.AddContent(" cell");
			text.AddContent("1", style2);
			text.AddContent(" content...");

			cell = row.AddCell();
			cell.ColSpan = 2;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("3", style2);
			text.AddContent(" cell");
			text.AddContent("2", style2);
			text.AddContent(" content...");
			text.Spacings.Bottom = 5;

			Siberix.Report.IImage image = cell.AddImage(img1);
			image.Width = new Siberix.Report.RelativeWidth(100);

			cell = row.AddCell();
			cell.RowSpan = 2;
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;
			cell.Background = new Siberix.Report.Background(new Siberix.Graphics.Color(230, 230, 230));

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("3", style2);
			text.AddContent(" cell");
			text.AddContent("3", style2);
			text.AddContent(" content...");

			row = grid.AddRow();

			cell = row.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("4", style2);
			text.AddContent(" cell");
			text.AddContent("1", style2);
			text.AddContent(" content...");

			cell = row.AddCell();
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Bottom;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;
			cell.Background = new Siberix.Report.Background(new Siberix.Graphics.Color(230, 230, 230));

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("4", style2);
			text.AddContent(" cell");
			text.AddContent("2", style2);
			text.AddContent(" content...");

			cell = row.AddCell();
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Bottom;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("row");
			text.AddContent("4", style2);
			text.AddContent(" cell");
			text.AddContent("3", style2);
			text.AddContent(" content...");

			System.Random rnd = new System.Random();

			for (int i = 5; i < 10; i++)
			{
				row = grid.AddRow();

				cell = row.AddCell();
				cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
				cell.Paddings.All = 5;

				text = cell.AddText();
				text.Style = style1;
				text.AddContent("row");
				text.AddContent(i.ToString(), style2);
				text.AddContent(" cell");
				text.AddContent("1", style2);
				text.AddContent(" content...");

				cell = row.AddCell();
				cell.ColSpan = 4;
				cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
				cell.Paddings.All = 5;

				text = cell.AddText();
				text.Style = style1;
				text.Spacings.Bottom = 5;
				text.AddContent("row");
				text.AddContent(i.ToString(), style2);
				text.AddContent(" cell");
				text.AddContent("2", style2);
				text.AddContent(" content... Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

				int j = 0;
				int cnt = rnd.Next(5);

				while (j < cnt)
				{
					j++;

					text.AddLineBreak();
					text.AddContent("... extra text line");
					text.AddContent(j.ToString(), style2);
				}
			}
		}

		#endregion

		#region AddSite

		private static void AddSite(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt3, Siberix.Graphics.Brushes.Red);

			// Site
			Siberix.Report.ISite site = section.AddSite();
			site.Width = new Siberix.Report.RelativeWidth(100);
			site.Height = new Siberix.Report.RelativeHeight(100);
			site.Borders = new Siberix.Report.Borders(new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Black, 1, Siberix.Graphics.DashStyle.Dot), 5);
			site.Paddings.All = 5;

			Siberix.Report.Text.IText text = site.AddText(10, 10);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:10, Top:10) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			text = site.AddText(150, 150, 45);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:150, Top:150, Angle:45) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			text = site.AddText(250, 100, -15);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:250, Top:100, Angle:-15) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			Siberix.Report.IImage image = site.AddImage(img1, 335, 240, -35);
			image.Width = new Siberix.Report.DirectWidth(150);
		}

		#endregion

		#region AddShapes

		private static void AddShapes(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);

			// Shapes
			Siberix.Report.ISite site = section.AddSite();

			// Rectangle
			Siberix.Report.Shapes.IRectangle rectangle = site.Shapes.AddRectangle();
			rectangle.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Red, 5);
			rectangle.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(255, 240, 240));
			rectangle.X = 30;
			rectangle.Y = 30;
			rectangle.Width = 150;
			rectangle.Height = 100;
			rectangle.Radius = 5;
			rectangle.Angle = 15;

			Siberix.Report.Shapes.ILabel label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 60;
			label.Y = 30;
			label.Text = "Rectangle";
			label.Angle = 15;

			// Line
			Siberix.Report.Shapes.ILine line = site.Shapes.AddLine();
			line.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Green, 5);
			line.X1 = 220;
			line.Y1 = 30;
			line.X2 = 320;
			line.Y2 = 130;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 250;
			label.Y = 35;
			label.Text = "Line";
			label.Angle = 45;

			// Ellipse
			Siberix.Report.Shapes.IEllipse ellipse = site.Shapes.AddEllipse();
			ellipse.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Blue, 5);
			ellipse.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(240, 240, 255));
			ellipse.X = 350;
			ellipse.Y = 30;
			ellipse.Width = 150;
			ellipse.Height = 100;
			ellipse.Angle = -20;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 400;
			label.Y = 80;
			label.Text = "Ellipse";
			label.Angle = -20;

			// Polyline
			Siberix.Report.Shapes.IPolyline polyline = site.Shapes.AddPolyline();
			polyline.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Green, 5, Siberix.Graphics.DashStyle.DashDot);

			Siberix.Graphics.PointCollection points = new Siberix.Graphics.PointCollection();
			points.Add(30, 200);
			points.Add(185, 220);
			points.Add(150, 350);
			points.Add(125, 260);
			points.Add(70, 300);
			polyline.Points = points;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 70;
			label.Y = 220;
			label.Text = "Polyline";
			label.Angle = 5;

			// Polygon
			Siberix.Report.Shapes.IPolygon polygon = site.Shapes.AddPolygon();
			polygon.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Goldenrod, 5);
			polygon.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(250, 250, 245));
			points = new Siberix.Graphics.PointCollection();
			points.Add(230, 200);
			points.Add(385, 220);
			points.Add(350, 350);
			points.Add(270, 300);
			polygon.Points = points;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 270;
			label.Y = 220;
			label.Text = "Polygon";
			label.Angle = 5;

			// Pie
			Siberix.Report.Shapes.IPie pie = site.Shapes.AddPie();
			pie.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkOrchid, 5);
			pie.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(250, 230, 250));
			pie.X = 400;
			pie.Y = 230;
			pie.Width = 100;
			pie.Height = 100;
			pie.StartAngle = -45;
			pie.EndAngle = 265;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 450;
			label.Y = 290;
			label.Text = "Pie";
			label.Angle = -40;

			// Path
			Siberix.Report.Shapes.IPath path = site.Shapes.AddPath();
			path.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkBlue, 5, Siberix.Graphics.DashStyle.DashDotDot);
			path.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(250, 250, 245));
			path.MoveTo(100, 400);
			path.LineTo(300, 500);
			path.CurveTo(120, 560, 100, 520, 70, 480);
			path.CurveTo(320, 360, 200, 320, 150, 600);
			path.ClosePath();

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 140;
			label.Y = 460;
			label.Text = "Path";

			// Arc
			Siberix.Report.Shapes.IArc arc = site.Shapes.AddArc();
			arc.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Red, 5);
			arc.X = 370;
			arc.Y = 420;
			arc.Width = 100;
			arc.Height = 100;
			arc.StartAngle = -45;
			arc.EndAngle = 265;

			label = site.Shapes.AddLabel();
			label.Font = style1.Font;
			label.Brush = Siberix.Graphics.Brushes.Black;
			label.X = 430;
			label.Y = 415;
			label.Text = "Arc";
			label.Angle = 15;
		}

		#endregion

		#region AddCanvas

		private static void AddCanvas(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt3, Siberix.Graphics.Brushes.Red);

			// Canvas
			Siberix.Report.ICanvas canvas = section.AddCanvas();
			canvas.Height = new Siberix.Report.DirectHeight(400);

			// Rectangle
			canvas.StartHyperlink(0, 0, 10);
			canvas.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Red, 5);
			canvas.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(255, 240, 240));
			canvas.DrawRectangle(50, 50, 150, 100, Siberix.Graphics.PaintMode.FillStroke);
			canvas.HyperlinkArea(50, 50, 150, 100);
			canvas.EndHyperlink();

			canvas.Font = fnt9;
			canvas.Brush = Siberix.Graphics.Brushes.BlueViolet;
			canvas.DrawString(70, 90, "Go to first page");

			// Line
			canvas.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Green, 5);
			canvas.DrawLine(220, 50, 320, 150);

			// Ellipse
			canvas.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Blue, 5);
			canvas.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(240, 240, 255));
			canvas.DrawEllipse(340, 50, 150, 100, Siberix.Graphics.PaintMode.FillStroke);

			// Path
			canvas.Pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkBlue, 5, Siberix.Graphics.DashStyle.DashDot);
			canvas.Brush = new Siberix.Graphics.LinearGradientBrush(Siberix.Graphics.Colors.Yellow, Siberix.Graphics.Colors.Green, 45F);

			canvas.StartShape(Siberix.Graphics.PaintMode.FillStroke);
			canvas.FillRectangle(120, 200, 200, 200);
			canvas.DrawEllipse(220, 250, 200, 200);
			canvas.EndShape();
		}

		#endregion

		#region AddBinding

		private static void AddBinding(Siberix.Report.Section.ISection section)
		{
			Person person1 = new Person() { Name = "John", Level = 3 };
			Person person2 = new Person() { Name = "Alex", Level = 2 };
			Person person3 = new Person() { Name = "Bob", Level = 7 };
			Person person4 = new Person() { Name = "Scott", Level = 1, Birthday = new DateTime(1965, 10, 23) };

			List<Task> tasks = new List<Task>();

			tasks.Add(new Task() { Id = "1-A11", Description = "Task 1" });
			tasks.Add(new Task() { Id = "2-B22", Description = "Task 2" });
			tasks.Add(new Task() { Id = "3-C33", Description = "Task 3" });
			tasks.Add(new Task() { Id = "4-D44", Description = "Task 4" });

			Person person5 = new Person() { Name = "Nick", Level = 1, Birthday = new DateTime(1975, 7, 16), Tasks = tasks };

			section.DataContext = new Siberix.Report.Data.DataContext("dc4", person4);

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.Red);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(fnt2, Siberix.Graphics.Brushes.DarkBlue);

			// Binding to the text.DataContext
			Siberix.Report.Text.IText text = section.AddText();
			text.DataContext = new Siberix.Report.Data.DataContext("dc1", person1);
			text.Binding = new Siberix.Report.Data.DataBinding("Name");
			text.Style = style1;



			// Binding with Formatter
			text = section.AddText();
			text.DataContext = new Siberix.Report.Data.DataContext("dc2", person2);
			text.Binding = new Siberix.Report.Data.DataBinding("Level", "Level: {0}");
			text.Style = style1;



			// Binding text to the parent DataContext with ValueFormatter
			text = section.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Birthday", "Birthday: *** {0} ***", new ValueFormatter());
			text.Style = style1;



			// Binding text to a specific DataContext
			text = section.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding(new Siberix.Report.Data.DataContext("dc3", person3), "Name", "Name: {0}");
			text.Style = style1;



			// Binding repeater to a collection of objects
			Siberix.Report.Repeater.IRepeater repeater = section.AddRepeater();
			repeater.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			repeater.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			repeater.Spacings.Top = 25;

			// Repeater item template
			Siberix.Report.Repeater.IItemTemplate repeaterItemTemplate = repeater.AddItemTemplate();

			text = repeaterItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description");
			text.Style = style1;



			// Binding list to a collection of objects
			Siberix.Report.List.IList list = section.AddList();
			list.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			list.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			list.Spacings.Top = 25;
			list.Bullets = new Siberix.Report.List.Bullets(Siberix.Report.BulletType.Circle, style1);

			// List item template
			Siberix.Report.List.IItemTemplate listItemTemplate = list.AddItemTemplate();

			text = listItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Id");
			text.Style = style1;

			text = listItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description", ": [ {0} ]");
			text.Style = style2;



			// Binding grid to a collection of objects
			Siberix.Report.Grid.IGrid grid = section.AddGrid();
			grid.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			grid.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			grid.Spacings.Top = 25;
			grid.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);

			Siberix.Report.Grid.IColumn column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(20);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(80);

			Siberix.Report.Grid.IHeader header = grid.AddHeader();

			Siberix.Report.Grid.IRow row = header.AddRow();

			Siberix.Report.Grid.ICell cell = row.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;
			cell.Background.Brush = Siberix.Graphics.Brushes.LightSeaGreen;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("Id");

			cell = row.AddCell();
			cell.ColSpan = 4;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;
			cell.Background.Brush = Siberix.Graphics.Brushes.LightSeaGreen;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("Description");

			// Grid row template
			Siberix.Report.Grid.IRowTemplate gridRowTemplate = grid.AddRowTemplate();

			cell = gridRowTemplate.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Id");
			text.Style = style1;

			cell = gridRowTemplate.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description", "--- {0} ---");
			text.Style = style3;
		}

		#endregion
	}
}